embassy-nrf

Crates

git

Versions

nrf9120-s

Flavors

Pin

Trait Pin 

pub trait Pin:
    PeripheralType
    + Into<AnyPin>
    + SealedPin
    + Sized
    + 'static {
    // Provided methods
    fn pin(&self) -> u8 { ... }
    fn port(&self) -> Port { ... }
    fn psel_bits(&self) -> Psel { ... }
}
Interface for a Pin that can be configured by an Input or Output driver, or converted to an AnyPin.

Provided Methods

fn pin(&self) -> u8

Number of the pin within the port (0..31)

fn port(&self) -> Port

Port of the pin

fn psel_bits(&self) -> Psel

Peripheral port register value

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors